@@ -80,10 +80,10 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                     item.addListener('tap',function(e){
                         try {
                             navigator.clipboard.writeText(item.getValue())
-                            .then(function(err){ msg.info(that.tr("Text Copied"),that.tr("The Text has been copied to clipboard"))})
-                            .catch(function(err){ msg.info(that.tr("Copy failed"),that.tr("Select text and press [ctr]+[c]")) });
+                            .then(function(ret){ msg.info(that.tr("Success"),that.tr("%1 copied to clipboard.",names[i]))})
+                            .catch(function(err){ msg.info(that.tr("Copy failed"),that.tr("Select %1 and press [ctrl]+[c]",names[i])) });
                         } catch (err) {
-                            msg.info(that.tr("Copy Failed"),that.tr("Select text with the Mouse and press [ctr]+[c]"))
+                            msg.info(that.tr("Copy failed"),that.tr("Select %1 and press [ctrl]+[c]",names[i]));
                         }
                     });
                 }
